@@ -44,7 +44,6 @@ else:
 load_env(environment)
 
 print(ShellColors.bright_yellow + "Setting debug mode", os.getenv("TINA4_DEBUG_LEVEL"), ShellColors.end)
-localize()
 
 if importlib.util.find_spec("jurigged"):
     import jurigged
@@ -52,10 +51,15 @@ if importlib.util.find_spec("jurigged"):
 # Define the variable to be used for global routes
 library_path = os.path.dirname(os.path.realpath(__file__))
 root_path = os.path.realpath(os.getcwd())
+
+if not os.path.exists(root_path + os.sep + "logs"):
+    os.makedirs(root_path + os.sep + "logs")
+
+localize()
+
 Debug(Messages.MSG_ASSUMING_ROOT_PATH.format(root_path=root_path, library_path=library_path),
       Constant.TINA4_LOG_INFO)
 
-
 tina4_routes = {}
 tina4_current_request = {}
 tina4_api_key = None
@@ -74,9 +78,6 @@ if "API_KEY" in os.environ:
 if root_path.count("tina4_python") > 0:
     root_path = root_path.split("tina4_python")[0][:-1]
 
-if not os.path.exists(root_path + os.sep + "logs"):
-    os.makedirs(root_path + os.sep + "logs")
-
 # Make the beginning files for the tina4stack
 if not os.path.exists(root_path + os.sep + "src"):
     os.makedirs(root_path + os.sep + "src" + os.sep + "routes")
@@ -114,28 +115,42 @@ if not os.path.exists(root_path + os.sep + "src" + os.sep + "public"):
 # ignore F403
 if os.path.exists(root_path + os.sep + "src"):
     try:
-        from src import *
-    except ImportError:
-        Debug("Cannot import src folder", Constant.TINA4_LOG_ERROR)
+        src_path = root_path + os.sep + "src"
+        for file in os.listdir(src_path):
+            if file.endswith(".py"):
+                file_name = file.removesuffix(".py")
+                exec("from src import "+ file_name)
+
+    except ImportError as e:
+        Debug("Cannot import src folder", str(e), Constant.TINA4_LOG_ERROR)
 else:
     Debug("Missing src folder", Constant.TINA4_LOG_WARNING)
 
 if os.path.exists(root_path + os.sep + "src" + os.sep + "routes"):
     try:
-        from src.routes import *
-    except ImportError:
-        Debug("Cannot import src.routes folder", Constant.TINA4_LOG_ERROR)
+        src_path = root_path + os.sep + "src"+ os.sep + "routes"
+        for file in os.listdir(src_path):
+            if file.endswith(".py"):
+                file_name = file.removesuffix(".py")
+                exec("from src.routes import "+ file_name)
+    except ImportError as e:
+        Debug("Cannot import src.routes folder", str(e), Constant.TINA4_LOG_ERROR)
 else:
     Debug("Missing src/routes folder", Constant.TINA4_LOG_WARNING)
 
 if os.path.exists(root_path + os.sep + "src" + os.sep + "app"):
     try:
-        from src.app import *
-    except ImportError:
-        Debug("Cannot import src.app folder", Constant.TINA4_LOG_ERROR)
+        src_path = root_path + os.sep + "src"+ os.sep + "app"
+        for file in os.listdir(src_path):
+            if file.endswith(".py"):
+                file_name = file.removesuffix(".py")
+                exec("from src.app import "+ file_name)
+    except ImportError as e:
+        Debug("Cannot import src.app folder", str(e), Constant.TINA4_LOG_ERROR)
 else:
     Debug("Missing src/app folder", Constant.TINA4_LOG_WARNING)
 
+
 # compile sass
 def compile_scss():
     try:
@@ -165,23 +180,30 @@ if os.path.exists(root_path + os.sep + "src" + os.sep + "scss"):
 else:
     Debug("Missing scss folder", Constant.TINA4_LOG_WARNING)
 
+
 # end compile sass
 
 
 def file_get_contents(file_path):
     return Path(file_path).read_text()
 
+
 # Add swagger routes
-@get("/swagger/swagger.json")
+@get(os.getenv("SWAGGER_ROUTE", "/swagger")+"/swagger.json")
 async def get_swagger_json(request, response):
     json = Swagger.get_json(request)
     return response(json)
 
-@get("/swagger")
+
+@get(os.getenv("SWAGGER_ROUTE", "/swagger"))
 async def get_swagger(request, response):
-    html = file_get_contents(root_path + os.sep +"src"+os.sep+"public"+ os.sep+"swagger"+os.sep+"index.html")
+    html = file_get_contents(
+        root_path + os.sep + "src" + os.sep + "public" + os.sep + "swagger" + os.sep + "index.html")
+
+    html = html.replace("{SWAGGER_ROUTE}", os.getenv("SWAGGER_ROUTE", "/swagger"))
     return response(html)
 
+
 def webserver(host_name, port):
     web_server = Webserver(host_name, int(port))  # HTTPServer((host_name, int(port)), Webserver)
     web_server.router_handler = Router()
@@ -201,7 +223,8 @@ def run_web_server(in_hostname="localhost", in_port=7145):
     Debug(Messages.MSG_STARTING_WEBSERVER.format(port=in_port), Constant.TINA4_LOG_INFO)
     webserver(in_hostname, in_port)
 
-if os.getenv('TINA4_DEFAULT_WEBSERVER', 'True') == 'True' :
+
+if os.getenv('TINA4_DEFAULT_WEBSERVER', 'True') == 'True':
     if importlib.util.find_spec("jurigged"):
         Debug("Jurigged enabled", Constant.TINA4_LOG_INFO)
         jurigged.watch("./")
